# -*- coding: utf-8 -*-
#
# Copyright (c) 2020, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from oser.core import Data as _Data


class Data(_Data):
    """
    ``Data`` builds a data serializer with fixed or variable length.
    Extends :class:`oser.String` but length must not be ``None``.
    """

    def __init__(self, length, value=b'', padding=b'\x00'):
        """
        Args:
            length: states the data length. Must be a callable (e.g. lambda).
            value="": the initial data value.
            padding=b"\x00": that padding pattern used for filling the encoded data if `value` is shorter than `length`.
        """
        super(Data, self).__init__(length=length, value=value, padding=padding)

    def decode(self, data, full_data=b'', context_data=b''):
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data (bytes): the data buffer that is decoded.
            full_data (bytes): the binary data string until the part to be decoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context. The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(Data, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data=b'', context_data=b''):
        """
        Return the encoded binary string.

        Args:
            full_data (bytes): the binary data string until the part to be
                encoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            bytes: the encoded binary string.
        """
        return super(Data, self).encode(full_data=full_data, context_data=context_data)

    def get(self):
        """
        Return the value.
        """
        return super(Data, self).get()

    def introspect(self, stop_at=None):
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None (object): stop introspection at ``stop_at``.
        """
        return super(Data, self).introspect(stop_at=stop_at)

    def root(self):
        """
        return root element
        """
        return super(Data, self).root()

    def set(self, value):
        """
        Set the value.

        Args:
            value: the new value
        """
        return super(Data, self).set(value=value)

    def set_fuzzing_values(self, values):
        """
        Set fuzzing values.

        Args:
            values (iterable): the values used for fuzzing.
        """
        return super(Data, self).set_fuzzing_values(values=values)

    def set_length(self, length):
        """
        Set the length.

        Args:
            length=None: states the string length. Can be a callable (e.g. lambda) or a scalar.
                If set to ``None`` the result is a null-terminated string.
                If set to an Integer the result is a fixed length string padded with ``padding``.
                If set to a ``callable`` (lambda or function) the result is a fixed or variable
                length string padded with ``padding``.
        """
        return super(Data, self).set_length(length=length)

    def size(self):
        """
        Return the size in bytes.
        """
        return super(Data, self).size()

    byte_size = size

    def up(self):
        """
        Return the parent element.
        """
        return super(Data, self).up()

