# -*- coding: utf-8 -*-
#
# Copyright (c) 2020, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from oser.core import ProtocolBuffersAdapter as _ProtocolBuffersAdapter


class ProtocolBuffersAdapter(_ProtocolBuffersAdapter):
    """
    ``ProtocolBuffersAdapter`` builds a Google Protocol Buffers adapter.
    """

    def __init__(self, instance=None, length=None):
        """
        Args:
            instance=None: an instance of a Google Protocol Buffers class.
            length=None: the length of the serialized data. If ``None`` the rest of the data is used so in most cases it should be a lambda expression. Look at the examples for more details.
        """
        super(ProtocolBuffersAdapter, self).__init__(instance=instance, length=length)

    def byte_size(self):
        """
        Return the size in bytes.
        """
        return super(ProtocolBuffersAdapter, self).byte_size()

    def decode(self, data, full_data=b'', context_data=b''):
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        If ``length`` is None, decoding is done iterative starting with the
        full buffer and removing one last byte after another until
        the buffer can be decoded. The buffer must fit the
        decoded message in protobuf and must not be longer or shorter.

        If decoding is not possible at all a ``DecodeException`` is raised.

        It is recommended not to set ``length`` to ``None`` even if it works.

        Args:
            data (bytes): the data buffer that is decoded.
            full_data (bytes): the binary data string until the part to be decoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context. The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(ProtocolBuffersAdapter, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data=b'', context_data=b''):
        """
        Return the encoded binary string.

        Args:
            full_data (bytes): the binary data string until the part to be
                encoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            bytes: the encoded binary string.
        """
        return super(ProtocolBuffersAdapter, self).encode(full_data=full_data, context_data=context_data)

    def get(self):
        """
        Return the protocol buffers instance.
        """
        return super(ProtocolBuffersAdapter, self).get()

    def introspect(self, stop_at=None):
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None (object): stop introspection at ``stop_at``.
        """
        return super(ProtocolBuffersAdapter, self).introspect(stop_at=stop_at)

    def root(self):
        """
        return root element
        """
        return super(ProtocolBuffersAdapter, self).root()

    def set(self, instance):
        """
        Set the protocol buffers instance.

        Args:
            instance (object): the protocol buffers instance
        """
        return super(ProtocolBuffersAdapter, self).set(instance=instance)

    def set_fuzzing_values(self, values):
        """
        Set fuzzing values.

        Args:
            values (iterable): the values used for fuzzing.
        """
        return super(ProtocolBuffersAdapter, self).set_fuzzing_values(values=values)

    def set_length(self, length):
        """
        Set the length.

        Args:
            length=None: states the string length. Can be a callable (e.g. lambda) or a scalar.
                If set to ``None`` the result is a null-terminated string.
                If set to an Integer the result is a fixed length string padded with ``padding``.
                If set to a ``callable`` (lambda or function) the result is a fixed or variable
                length string padded with ``padding``.
        """
        return super(ProtocolBuffersAdapter, self).set_length(length=length)

    def size(self):
        """
        Return the size in bytes.
        """
        return super(ProtocolBuffersAdapter, self).size()

    def up(self):
        """
        Return the parent element.
        """
        return super(ProtocolBuffersAdapter, self).up()

